@@ -28,7 +28,7 @@
 
 set dirlist = `ls testA*.sh`
 foreach i ($dirlist)
-	./$i
+	csh ./$i
 end
 
 rm -fr *.output
